#[non_exhaustive]pub enum PeriodicColumnShapeError {
LengthNotPowerOfTwo {
index: usize,
length: usize,
},
LengthNotDividingHeight {
index: usize,
length: usize,
height: usize,
},
}Expand description
Why a declared periodic column cannot be laid over a trace of a given height.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LengthNotPowerOfTwo
A length with no subgroup of that order to interpolate over.
Fields
LengthNotDividingHeight
A length that cannot tile the rows it has to cover.